@@ -68,7 +68,11 @@ class Cube():
     # Before run starts
     def __init_run(self):
         # init run dir
-        base_dir = './runs'
+        if 'save_dir' not in self.config['hparam'].keys():
+            base_dir = './runs'
+        else:
+            base_dir = self.config['hparam']['save_dir']
+
         run_name = f"{self.config['hparam']['run_name']}_{utils.get_time()}"
         run_dir = f'{base_dir}/{run_name}'
         checkpoint_dir = f'{run_dir}/checkpoints'
